@@ -14,11 +14,12 @@
     You should have received a copy of the GNU General Public License
     along with this program.  If not, see <http://www.gnu.org/licenses/>.  '''
 
-__version__ = "0.3.20"
+__version__ = "0.3.21"
 __author__ = "nagev"
 __license__ = "GPLv3"
 
 import re
+import os
 import sys
 import time
 import json
@@ -37,7 +38,8 @@ else:
     from urllib import unquote_plus
     from urlparse import parse_qs
 
-#logging.basicConfig(level=logging.DEBUG)
+if os.path.exists(os.path.join(os.path.expanduser("~"), ".pafydebug")):
+    logging.basicConfig(level=logging.DEBUG)
 
 
 def _extract_function_from_js(name, js):
@@ -132,23 +134,23 @@ def new(url):
 
 class Stream():
     itags = {
-        '5': ('320x240', 'flv', "a/v"),
-        '17': ('176x144', '3gp', "a/v"),
-        '18': ('640x360', 'mp4', "a/v"),
-        '22': ('1280x720', 'mp4', "a/v"),
-        '34': ('360x640', 'flv', "a/v"),
-        '35': ('480x854', 'flv', "a/v"),
-        '36': ('320x240', '3gp', "a/v"),
-        '37': ('1920x1080', 'mp4', "a/v"),
-        '38': ('4096x3072', 'superHD', "a/v"),
-        '43': ('640x360', 'webm', "a/v"),
-        '44': ('480x854', 'webm', "a/v"),
-        '45': ('720x1280', 'webm', "a/v"),
-        '46': ('1080x1920', 'webm', "a/v"),
-        '82': ('640x360-3D', 'mp4', "a/v"),
-        '84': ('1280x720-3D', 'mp4', "a/v"),
-        '100': ('640x360-3D', 'webm', "a/v"),
-        '102': ('1280x720-3D', 'webm', "a/v"),
+        '5': ('320x240', 'flv', "normal"),
+        '17': ('176x144', '3gp', "normal"),
+        '18': ('640x360', 'mp4', "normal"),
+        '22': ('1280x720', 'mp4', "normal"),
+        '34': ('360x640', 'flv', "normal"),
+        '35': ('854x480', 'flv', "normal"),
+        '36': ('320x240', '3gp', "normal"),
+        '37': ('1920x1080', 'mp4', "normal"),
+        '38': ('4096x3072', 'superHD', "normal"),
+        '43': ('640x360', 'webm', "normal"),
+        '44': ('854x480', 'webm', "normal"),
+        '45': ('720x1280', 'webm', "normal"),
+        '46': ('1080x1920', 'webm', "normal"),
+        '82': ('640x360-3D', 'mp4', "normal"),
+        '84': ('1280x720-3D', 'mp4', "normal"),
+        '100': ('640x360-3D', 'webm', "normal"),
+        '102': ('1280x720-3D', 'webm', "normal"),
         '133': ('426x240', 'm4v', 'video'),
         '134': ('640x360', 'm4v', 'video'),
         '135': ('854x480', 'm4v', 'video'),
@@ -160,7 +162,7 @@ class Stream():
         '141': ('256k', 'm4a', 'audio'),
         '160': ('256x144', 'm4v', 'video'),
         '171': ('128k', 'ogg', 'audio'),
-        '172': ('256k', 'ogg', 'audio'),
+        '172': ('192k', 'ogg', 'audio'),
         '248': ('unknown', 'unknown', 'unknown')
     }
 
@@ -176,6 +178,7 @@ class Stream():
             self.url = self.url + "&ratebypass=yes"
         self.itag = streammap['itag'][0]
         logging.debug("itag %s" % self.itag)
+        logging.debug("stream map: %s" % streammap)
         self.vidformat = streammap['type'][0].split(';')[0]
         self.resolution = self.itags[self.itag][0]
         self.quality = self.resolution
